#
# spec file for package systemtap
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           systemtap
BuildRequires:  gcc-c++
BuildRequires:  glib2-devel
BuildRequires:  libcap-devel
BuildRequires:  libebl-devel
BuildRequires:  mozilla-nspr-devel
BuildRequires:  mozilla-nss-devel
BuildRequires:  mozilla-nss-tools
BuildRequires:  pkg-config
BuildRequires:  sqlite-devel
BuildRequires:  systemd
Version:        2.3
Release:        0
Summary:        Instrumentation System
License:        GPL-2.0+
Group:          Development/Tools/Debuggers
Url:            http://sourceware.org/systemtap/
Source:         http://sourceware.org/systemtap/ftp/releases/systemtap-%{version}.tar.gz
Source2:        README-BEFORE-ADDING-PATCHES
Source3:        stap-server.conf
Patch1:         systemtap-build-source-dir.patch
Obsoletes:      systemtap-client < 1.5
Requires:       %{name}-runtime = %{version}-%{release}
Requires:       libebl1
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
SystemTap is an instrumentation system for systems running Linux.
Developers can write instrumentation to collect data on the operation
of the system.

%package runtime
Summary:        Runtime environment for systemtap
Group:          Development/Tools/Debuggers

%description runtime
SystemTap is an instrumentation system for systems running Linux.
This package contains the runtime environment for systemtap programs.

%package server
Summary:        Systemtap server
Group:          Development/Tools/Debuggers
Requires:       %{name} = %{version}-%{release}
# needed for systemd-tmpfiles
Requires(post): systemd
# dependancies for systemtap shell scripts
Requires:       avahi
Requires:       avahi-utils
Requires:       coreutils
Requires:       mozilla-nss-tools
Requires:       unzip
Requires:       zip

%description server
SystemTap is an instrumentation system for systems running Linux.
This package contains the server component of systemtap.

%package sdt-devel
Summary:        Static probe support tools
Group:          Development/Tools/Debuggers
Requires:       %{name} = %{version}-%{release}
Requires:       python-base

%description sdt-devel
SystemTap is an instrumentation system for systems running Linux.
This package contains the support tools for static probes.

%prep
%setup -q
%patch1 -p1

%build
%configure --disable-docs --docdir=%{_docdir}/systemtap
make %{?jobs:-j %jobs}

%install
%makeinstall
# XXX
rm -f $RPM_BUILD_ROOT/usr/lib/systemtap/stap-server-request
# README, AUTHORS, NEWS, man3 and all examples packaged by systemtap-docs
# COPYING needs to stay in main for GPL
rm -rf $RPM_BUILD_ROOT%{_docdir}/systemtap/
rm -rf $RPM_BUILD_ROOT%{_mandir}/man3
mkdir -p $RPM_BUILD_ROOT%{_docdir}/systemtap/
cp COPYING $RPM_BUILD_ROOT%{_docdir}/systemtap/
mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/cache/systemtap
mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/log
touch $RPM_BUILD_ROOT%{_localstatedir}/log/stap-server.log
# config file for stap-server (/var/run now on tmpfs)
mkdir -p $RPM_BUILD_ROOT/usr/lib/tmpfiles.d
install -m 644 %SOURCE3 $RPM_BUILD_ROOT/usr/lib/tmpfiles.d

%{find_lang} systemtap

%clean
rm -rf ${RPM_BUILD_ROOT}

%post server
# Create tmpfiles
systemd-tmpfiles --create /usr/lib/tmpfiles.d/stap-server.conf

%files
%defattr(-,root,root)
%{_bindir}/stap
%{_mandir}/man[17]/*
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/runtime
%{_datadir}/%{name}/tapset
#packaged by systemtap-initscript in upstream
%dir %{_localstatedir}/cache/systemtap

%files runtime -f systemtap.lang
%defattr(-,root,root)
%doc %{_docdir}/systemtap
%{_bindir}/staprun
%{_bindir}/stapsh
%{_bindir}/stap-merge
%{_bindir}/stap-report
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/stapio
%{_libexecdir}/%{name}/stap-env
%{_libexecdir}/%{name}/stap-authorize-cert
%{_mandir}/man8/staprun.8*
%{_mandir}/man8/stapsh.8*

%files server
%defattr(-,root,root)
%dir /usr/lib/tmpfiles.d
/usr/lib/tmpfiles.d/stap-server.conf
%{_bindir}/stap-server
%{_libexecdir}/%{name}/stap-gen-cert
%{_libexecdir}/%{name}/stap-serverd
%{_libexecdir}/%{name}/stap-sign-module
%{_libexecdir}/%{name}/stap-start-server
%{_libexecdir}/%{name}/stap-stop-server
%{_mandir}/man8/stap-server.8*
%ghost %{_localstatedir}/log/stap-server.log
%ghost %dir %{_localstatedir}/run/stap-server

%files sdt-devel
%defattr(-,root,root)
%{_bindir}/dtrace
%{_includedir}/sys/*.h

%changelog
